import { Construct } from 'constructs';
import * as iam from 'aws-cdk-lib/aws-iam';
import { RemovalPolicy, Resource } from 'aws-cdk-lib/core';
import { ITableBucket } from './table-bucket';
/**
 * Parameters for constructing a TableBucketPolicy
 */
export interface TableBucketPolicyProps {
    /**
     * The associated table bucket
     */
    readonly tableBucket: ITableBucket;
    /**
     * The policy document for the bucket's resource policy
     * @default undefined An empty iam.PolicyDocument will be initialized
     */
    readonly resourcePolicy?: iam.PolicyDocument;
    /**
     * Policy to apply when the policy is removed from this stack.
     *
     * @default - RemovalPolicy.DESTROY.
     */
    readonly removalPolicy?: RemovalPolicy;
}
/**
 * A Bucket Policy for S3 TableBuckets.
 *
 * You will almost never need to use this construct directly.
 * Instead, TableBucket.addToResourcePolicy can be used to add more policies to your bucket directly
 */
export declare class TableBucketPolicy extends Resource {
    /**
     * The IAM PolicyDocument containing permissions represented by this policy.
     */
    readonly document: iam.PolicyDocument;
    /**
     * @internal The underlying policy resource.
     */
    private readonly _resource;
    constructor(scope: Construct, id: string, props: TableBucketPolicyProps);
}
